"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var color_1 = require("tns-core-modules/color");
var frame_1 = require("tns-core-modules/ui/frame");
var ColorPickerImpl = (function (_super) {
    __extends(ColorPickerImpl, _super);
    function ColorPickerImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorPickerImpl.initWithOwner = function (owner) {
        var handler = ColorPickerImpl.new();
        handler._owner = owner;
        return handler;
    };
    ColorPickerImpl.prototype.dismissViewController = function (sender) {
        var owner = this._owner.get();
        if (owner) {
            owner._dismissViewController(sender);
        }
    };
    ColorPickerImpl.ObjCExposedMethods = {
        dismissViewController: { returns: interop.types.void, params: [] }
    };
    return ColorPickerImpl;
}(NSObject));
var ColorPicker = (function () {
    function ColorPicker() {
    }
    ColorPicker.prototype.show = function (initialColor, colorMode) {
        var _this = this;
        if (initialColor === void 0) { initialColor = '#FF4081'; }
        if (colorMode === void 0) { colorMode = 'RGB'; }
        return new Promise(function (resolve, reject) {
            try {
                _this._doneResolve = resolve;
                var colorSelectionController = new MSColorSelectionViewController(null);
                colorSelectionController.color = new color_1.Color(initialColor).ios;
                var navCtrl = UINavigationController.alloc().initWithRootViewController(colorSelectionController);
                var delegate = NSObject
                    .extend({
                    colorViewControllerDidChangeColor: function (colorViewCntroller, color) {
                        var components = CGColorGetComponents(color.CGColor);
                        var red = lroundf(components[0] * 255);
                        var green = lroundf(components[1] * 255);
                        var blue = lroundf(components[2] * 255);
                        var alpha = lroundf(components[3] * 255);
                        switch (colorMode) {
                            case 'ARGB':
                                ColorPicker.COLOR = new color_1.Color(alpha, red, green, blue).argb;
                                break;
                            case 'RGB':
                                ColorPicker.COLOR = red + ', ' + green + ', ' + blue;
                                break;
                            case 'HEX':
                                ColorPicker.COLOR = this.rgb2hex(red + ', ' + green + ', ' + blue + ', ' + alpha);
                                break;
                            default:
                                ColorPicker.COLOR = undefined;
                                resolve('Not supported on iOS');
                                break;
                        }
                    },
                    rgb2hex: function (rgb) {
                        var match = rgb.match(/[\s+]?[\s+]?(\d+)[\s+]?,[\s+]?(\d+)[\s+]?,[\s+]?(\d+)[\s+]?/);
                        return match && match.length === 4
                            ? '#' +
                                ('0' + parseInt(match[1], 10).toString(16)).slice(-2) +
                                ('0' + parseInt(match[2], 10).toString(16)).slice(-2) +
                                ('0' + parseInt(match[3], 10).toString(16)).slice(-2)
                            : '';
                    }
                }, {
                    protocols: [MSColorSelectionViewControllerDelegate]
                })
                    .alloc()
                    .init();
                colorSelectionController.delegate = delegate;
                _this._impl = ColorPickerImpl.initWithOwner(new WeakRef(_this));
                var doneBtn = UIBarButtonItem.alloc().initWithTitleStyleTargetAction('Done', 2, _this._impl, 'dismissViewController');
                colorSelectionController.navigationItem.rightBarButtonItem = doneBtn;
                frame_1.topmost().currentPage.ios.presentViewControllerAnimatedCompletion(navCtrl, true, null);
            }
            catch (err) {
                reject(err);
            }
        });
    };
    ColorPicker.prototype._dismissViewController = function (sender) {
        if (this._doneResolve) {
            this._doneResolve(ColorPicker.COLOR);
        }
        frame_1.topmost().currentPage.ios.dismissViewControllerAnimatedCompletion(true, null);
    };
    return ColorPicker;
}());
exports.ColorPicker = ColorPicker;
